@@ -3,17 +3,23 @@ NULL
 
 #' Convert GSEABase classes to a TidySet
 #' @param object A GeneSetCollection or a GeneSet derived object
-#' @return A TidySet object
+#' @return A TidySet object.
 #' @export
 tidy <- function(object) {
     UseMethod("tidy")
 }
 
+#' @export
+tidy.default <- function(object) {
+    tidySet(object)
+}
+
 #' @describeIn tidy Converts to a tidySet given a GeneSetCollection
 #' @export
 #' @method tidy GeneSetCollection
 #' @examples
-#' if (requireNamespace("GSEABase")) {
+#' # Needs GSEABase pacakge from Bioconductor
+#' if (requireNamespace("GSEABase", quietly = TRUE)) {
 #'     library("GSEABase")
 #'     gs <- GeneSet()
 #'     gs
